<?php

global $reports_text;
$reports_text = array (

'summary'	=>	'Skrócony opis',

'changelog'	=>	'Lista zmian',
'changeloggen'	=>	'Generator listy zmian',
'listfrom'	=>	'Pokaż zmiany od',
'to'		=>	'do',
'show'		=>	'Pokaż',
'oldestfirst'	=>	'Sortuj od najstarszych',
'recentfirst'	=>	'Sortuj od najnowszych',

'severity'	=>	'Ważność',
'severityrep'	=>	'Raport dotkliwości',
'totalopen'	=>	'Całkowita liczba otwartych',

'age'		=>	'Wiek',
'agerep'	=>	'Raport wieku',

'eventsrep'     =>      'Raport zdarzeń',
'events'        =>      'Zdarzenia',
'tasks'         =>      'Zgłoszenia',
'opened'        =>      'Otwarte',
'closed'        =>      'Zamknięte',
'edited'        =>      'Zmieniane',
'assigned'      =>      'Przydzielone',
'comments'      =>      'Komentarze',
'attachments'   =>      'Załączniki',
'relatedtasks'  =>      'Powiązane zgłoszenia',
'notifications' =>      'Powiadomienia',
'reminders'     =>      'Przypomnienia',
'within'        =>      'Okres',

'pastday'       =>      'wczoraj',
'pastweek'      =>      'w zeszłym tygodniu',
'pastmonth'     =>      'w zeszłym miesiącu',
'pastyear'      =>      'w zeszłym roku',
'nolimit'       =>      'bez ograniczeń',

'from'          =>      'Zakres dni',
'duein'         =>      'Do wersji',

'changelog'     =>      'Lista zmian',
'date'          =>      'Data',

);
// vim:fenc=utf-8:enc=utf-8
?>
